@@ -18,8 +18,10 @@ import logging
 from gettext import gettext as _
 
 from gi.repository import GObject
+from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import GdkX11
 
 from sugar3.graphics.icon import Icon
 from sugar3.graphics import style
@@ -37,7 +39,8 @@ _logger = logging.getLogger('ControlPanel')
 class ControlPanel(Gtk.Window):
     __gtype_name__ = 'SugarControlPanel'
 
-    def __init__(self):
+    def __init__(self, window_xid=0):
+        self.parent_window_xid = window_xid
         Gtk.Window.__init__(self)
 
         self._calculate_max_columns()
@@ -88,7 +91,14 @@ class ControlPanel(Gtk.Window):
 
     def __realize_cb(self, widget):
         self.set_type_hint(Gdk.WindowTypeHint.DIALOG)
-        self.get_window().set_accept_focus(True)
+        window = self.get_window()
+        window.set_accept_focus(True)
+        if self.parent_window_xid > 0:
+            display = Gdk.Display.get_default()
+            parent = GdkX11.X11Window.foreign_new_for_display(
+                display, self.parent_window_xid)
+            window.set_transient_for(parent)
+
         # the modal windows counter is updated to disable hot keys - SL#4601
         shell.get_model().push_modal()
 
@@ -423,7 +433,7 @@ class ControlPanel(Gtk.Window):
             self._section_toolbar.accept_button.set_sensitive(False)
             self._section_toolbar.cancel_button.set_sensitive(False)
             get_session_manager().logout()
-            GObject.timeout_add_seconds(4, self.__quit_timeout_cb)
+            GLib.timeout_add_seconds(4, self.__quit_timeout_cb)
 
     def __quit_timeout_cb(self):
         self.unbusy()
@@ -502,10 +512,10 @@ class _SectionIcon(Gtk.EventBox):
     __gtype_name__ = 'SugarSectionIcon'
 
     __gproperties__ = {
-        'icon-name': (str, None, None, None, GObject.PARAM_READWRITE),
-        'pixel-size': (object, None, None, GObject.PARAM_READWRITE),
-        'xo-color': (object, None, None, GObject.PARAM_READWRITE),
-        'title': (str, None, None, None, GObject.PARAM_READWRITE),
+        'icon-name': (str, None, None, None, GObject.ParamFlags.READWRITE),
+        'pixel-size': (object, None, None, GObject.ParamFlags.READWRITE),
+        'xo-color': (object, None, None, GObject.ParamFlags.READWRITE),
+        'title': (str, None, None, None, GObject.ParamFlags.READWRITE),
     }
 
     def __init__(self, **kwargs):
