@@ -415,6 +415,11 @@ class BaseListView(Gtk.Bin):
         self.tree_view.queue_draw_area(cell_rect.x, cell_rect.y,
                                        cell_rect.width, cell_rect.height)
 
+        # HACK for https://bugs.sugarlabs.org/ticket/4944
+        # Icon does not update automatically if there is only one journal entry
+        if len(self._model.get_all_ids()) == 1:
+            self._do_refresh()
+
     def __select_set_data_cb(self, column, cell, tree_model, tree_iter,
                              data):
         uid = tree_model[tree_iter][ListModel.COLUMN_UID]
@@ -450,7 +455,7 @@ class BaseListView(Gtk.Bin):
         window = self.get_toplevel().get_window()
         if window is not None:
             window.set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
-        GObject.idle_add(self._do_refresh, new_query)
+        GLib.idle_add(self._do_refresh, new_query)
 
     def _do_refresh(self, new_query=False):
         if self._model is not None:
@@ -511,12 +516,12 @@ class BaseListView(Gtk.Bin):
                     else:
                         self._show_message(_('The device is empty'))
                 else:
-                    show_message_text = 'No matching entries'
+                    show_message_text = _('No matching entries')
                     if self.get_projects_view_active():
-                        show_message_text = 'No Projects'
+                        show_message_text = _('No Projects')
 
-                self._show_message(_(show_message_text),
-                                   show_clear_query=self._can_clear_query())
+                    self._show_message(show_message_text,
+                        show_clear_query=self._can_clear_query())
         else:
             self._clear_message()
 
@@ -672,13 +677,13 @@ class BaseListView(Gtk.Bin):
             if self._update_dates_timer is None:
                 logging.debug('Adding date updating timer')
                 self._update_dates_timer = \
-                    GObject.timeout_add_seconds(UPDATE_INTERVAL,
-                                                self.__update_dates_timer_cb)
+                    GLib.timeout_add_seconds(UPDATE_INTERVAL,
+                                             self.__update_dates_timer_cb)
         else:
             self._fully_obscured = True
             if self._update_dates_timer is not None:
                 logging.debug('Remove date updating timer')
-                GObject.source_remove(self._update_dates_timer)
+                GLib.source_remove(self._update_dates_timer)
                 self._update_dates_timer = None
 
     def __update_dates_timer_cb(self):
@@ -802,9 +807,7 @@ class ListView(BaseListView):
 
     def __cell_title_edited_cb(self, cell, path, new_text):
         iterator = self._model.get_iter(path)
-        if not new_text.isspace() and not new_text == '':
-            self._model[iterator][ListModel.COLUMN_TITLE] = new_text
-
+        self._model[iterator][ListModel.COLUMN_TITLE] = new_text
         self.emit('title-edit-finished')
 
     def __editing_canceled_cb(self, cell):
@@ -877,4 +880,4 @@ class CellRendererBuddy(CellRendererIcon):
             self.props.icon_name = 'computer-xo'
             self.props.xo_color = xo_color
 
-    buddy = GObject.property(type=object, setter=set_buddy)
+    buddy = GObject.Property(type=object, setter=set_buddy)
