@@ -20,6 +20,7 @@ import logging
 import os
 
 from gi.repository import GObject
+from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import Gio
@@ -200,7 +201,11 @@ class ObjectPalette(Palette):
     def __erase_alert_response_cb(self, alert, response_id):
         journalwindow.get_journal_window().remove_alert(alert)
         if response_id is Gtk.ResponseType.OK:
-            model.delete(self._metadata['uid'])
+            uid = self._metadata['uid']
+            list_model = self._journalactivity.get_list_view().get_model()
+            if list_model.is_selected(uid):
+                list_model.set_selected(uid, False)
+            model.delete(uid)
 
     def __detail_activate_cb(self, menu_item):
         self.emit('detail-clicked', self._metadata['uid'])
@@ -592,7 +597,7 @@ class BatchOperator(GObject.GObject):
 
     def _show_confirmation_alert(self):
         self._journalactivity.freeze_ui()
-        GObject.idle_add(self.__show_confirmation_alert_internal)
+        GLib.idle_add(self.__show_confirmation_alert_internal)
 
     def __show_confirmation_alert_internal(self):
         # Show a alert requesting confirmation before run the batch operation
@@ -622,16 +627,9 @@ class BatchOperator(GObject.GObject):
             # this is only in the case the operation already started
             # and the user want stop it.
             self._stop_batch_execution()
-        else:
-            GObject.idle_add(self._prepare_batch_execution)
-
-    def _prepare_batch_execution(self):
-        self._object_index = 0
-        # Next, proceed with the objects
-        self._operate_by_uid()
-
-    def _operate_by_uid(self):
-        GObject.idle_add(self._operate_by_uid_internal)
+        elif hasattr(self, '_object_index') == False:
+            self._object_index = 0
+            GLib.idle_add(self._operate_by_uid_internal)
 
     def _operate_by_uid_internal(self):
         # If there is still some uid left, proceed with the operation.
@@ -650,7 +648,7 @@ class BatchOperator(GObject.GObject):
                 'object_title': title}
 
             self._confirmation_alert.props.msg = alert_message
-            GObject.idle_add(self._operate_per_metadata, metadata)
+            GLib.idle_add(self._operate_per_metadata, metadata)
         else:
             self._finish_batch_execution()
 
@@ -659,12 +657,13 @@ class BatchOperator(GObject.GObject):
 
         # process the next
         self._object_index = self._object_index + 1
-        GObject.idle_add(self._operate_by_uid_internal)
+        GLib.idle_add(self._operate_by_uid_internal)
 
     def _stop_batch_execution(self):
         self._object_index = len(self._uid_list)
 
     def _finish_batch_execution(self):
+        del self._object_index
         self._journalactivity.unfreeze_ui()
         self._journalactivity.remove_alert(self._confirmation_alert)
         self._journalactivity.update_selected_items_ui()
