@@ -25,6 +25,7 @@ from gettext import gettext as _
 import gi
 gi.require_version('GtkSource', '3.0')
 from gi.repository import GObject
+from gi.repository import GLib
 from gi.repository import Pango
 from gi.repository import Gtk
 from gi.repository import Gdk
@@ -104,7 +105,7 @@ def _get_toolkit_path(bundle_path, bundle_id):
         sugar_module = 'sugar'
 
     for path in sys.path:
-        if path.endswith('site-packages'):
+        if path.endswith(('site-packages', 'dist-packages')):
             sugar_toolkit_path = os.path.join(path, sugar_module)
             if os.path.exists(sugar_toolkit_path):
                 return sugar_toolkit_path
@@ -123,9 +124,9 @@ def setup_view_source(activity):
                 'org.freedesktop.DBus.Error.UnknownMethod',
                 'org.freedesktop.DBus.Python.NotImplementedError']
             if e.get_dbus_name() not in expected_exceptions:
-                logging.exception('Exception occured in HandleViewSource():')
+                logging.exception('Exception occurred in HandleViewSource():')
         except Exception:
-            logging.exception('Exception occured in HandleViewSource():')
+            logging.exception('Exception occurred in HandleViewSource():')
 
     window_xid = activity.get_xid()
     if window_xid is None:
@@ -149,9 +150,9 @@ def setup_view_source(activity):
                 'org.freedesktop.DBus.Error.UnknownMethod',
                 'org.freedesktop.DBus.Python.NotImplementedError']
             if e.get_dbus_name() not in expected_exceptions:
-                logging.exception('Exception occured in GetDocumentPath():')
+                logging.exception('Exception occurred in GetDocumentPath():')
         except Exception:
-            logging.exception('Exception occured in GetDocumentPath():')
+            logging.exception('Exception occurred in GetDocumentPath():')
 
     if bundle_path is None and document_path is None:
         _logger.debug('Activity without bundle_path nor document_path')
@@ -179,6 +180,7 @@ class ViewSource(Gtk.Window):
         _logger.debug('ViewSource paths: %r %r %r', bundle_path,
                       document_path, sugar_toolkit_path)
 
+        self.set_modal(True)
         self.set_decorated(False)
         self.set_position(Gtk.WindowPosition.CENTER_ALWAYS)
         self.set_border_width(style.LINE_WIDTH)
@@ -409,7 +411,7 @@ class DocumentButton(RadioToolButton):
             new_alert.props.title = _("Duplicating activity...")
 
             self.get_toplevel().add_alert(new_alert)
-            GObject.idle_add(internal_callback, new_alert)
+            GLib.idle_add(internal_callback, new_alert)
 
     def __set_busy_cursor(self, busy):
         cursor = None
@@ -452,7 +454,7 @@ class DocumentButton(RadioToolButton):
                 finally:
                     self.__set_busy_cursor(False)
 
-            GObject.idle_add(async_copy_activity_tree)
+            GLib.idle_add(async_copy_activity_tree)
         else:
             if copy_alert:
                 self.get_toplevel().remove_alert(copy_alert)
@@ -686,6 +688,8 @@ class FileViewer(Gtk.ScrolledWindow):
 
     def __cursor_changed_cb(self, treeview):
         selection = treeview.get_selection()
+        if selection is None:
+            return
         store, iter_ = selection.get_selected()
         if iter_ is None:
             # Nothing selected. This happens at startup
@@ -788,8 +792,7 @@ class SourceDisplay(Gtk.ScrolledWindow):
     file_path = property(_get_file_path, _set_file_path)
 
     def _show_image_viewer(self, icon=None, image=False):
-        media_box = Gtk.EventBox()
-        media_box.modify_bg(Gtk.StateType.NORMAL, Gdk.color_parse('white'))
+        media_box = ImageBox()
 
         if image:
             image = Gtk.Image()
@@ -815,3 +818,10 @@ class SourceDisplay(Gtk.ScrolledWindow):
         nofile_box.add(nofile_label)
         nofile_box.show_all()
         self._replace_with_viewport(nofile_box)
+
+
+class ImageBox(Gtk.EventBox):
+    __gtype_name__ = 'SugarViewSourceImageBox'
+
+    def __init__(self):
+        Gtk.EventBox.__init__(self)
